==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodChaosSpecBuilder extends PodChaosSpecFluentImpl<PodChaosSpecBuilder> implements VisitableBuilder<PodChaosSpec,PodChaosSpecBuilder>{
  public PodChaosSpecBuilder() {
    this(false);
  }
  public PodChaosSpecBuilder(Boolean validationEnabled) {
    this(new PodChaosSpec(), validationEnabled);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodChaosSpec(), validationEnabled);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance) {
    this(fluent, instance, false);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withContainerNames(instance.getContainerNames());
      fluent.withDuration(instance.getDuration());
      fluent.withGracePeriod(instance.getGracePeriod());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodChaosSpecBuilder(PodChaosSpec instance) {
    this(instance,false);
  }
  public PodChaosSpecBuilder(PodChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withContainerNames(instance.getContainerNames());
      this.withDuration(instance.getDuration());
      this.withGracePeriod(instance.getGracePeriod());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public PodChaosSpec build() {
    PodChaosSpec buildable = new PodChaosSpec(fluent.getAction(),fluent.getContainerNames(),fluent.getDuration(),fluent.getGracePeriod(),fluent.getMode(),fluent.getSelector(),fluent.getValue());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodChaosSpecBuilder extends PodChaosSpecFluent<PodChaosSpecBuilder> implements VisitableBuilder<PodChaosSpec,PodChaosSpecBuilder>{
  public PodChaosSpecBuilder() {
    this(false);
  }
  public PodChaosSpecBuilder(Boolean validationEnabled) {
    this(new PodChaosSpec(), validationEnabled);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodChaosSpec(), validationEnabled);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance) {
    this(fluent, instance, false);
  }
  public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodChaosSpec());

    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withContainerNames(instance.getContainerNames());
      fluent.withDuration(instance.getDuration());
      fluent.withGracePeriod(instance.getGracePeriod());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withValue(instance.getValue());
      fluent.withAction(instance.getAction());
      fluent.withContainerNames(instance.getContainerNames());
      fluent.withDuration(instance.getDuration());
      fluent.withGracePeriod(instance.getGracePeriod());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodChaosSpecBuilder(PodChaosSpec instance) {
    this(instance,false);
  }
  public PodChaosSpecBuilder(PodChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodChaosSpec());

    if (instance != null) {
      this.withAction(instance.getAction());
      this.withContainerNames(instance.getContainerNames());
      this.withDuration(instance.getDuration());
      this.withGracePeriod(instance.getGracePeriod());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withValue(instance.getValue());
      this.withAction(instance.getAction());
      this.withContainerNames(instance.getContainerNames());
      this.withDuration(instance.getDuration());
      this.withGracePeriod(instance.getGracePeriod());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public PodChaosSpec build() {
    PodChaosSpec buildable = new PodChaosSpec(fluent.getAction(),fluent.getContainerNames(),fluent.getDuration(),fluent.getGracePeriod(),fluent.getMode(),fluent.buildSelector(),fluent.getValue());
    return buildable;
  }
  
}
